import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

import backstageRouter from './modules/backstage'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [{
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [{
      path: '/redirect/:path*',
      component: () => import('@/views/redirect/index')
    }]
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  {
    path: "/",
    component: Layout,
    redirect: "/dashboard",
    children: [{
      path: "dashboard",
      name: "Dashboard",
      component: () => import("@/views/dashboard/index"),
      meta: {
        title: "首页",
        icon: "home",
        affix: true,
      }
    }]
  },

]

/**
 * 拥有角色权限才能看到的路由
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  // {
  //   path: '/',
  //   component: Layout,
  //   redirect: '/dashboard',
  //   children: [{
  //     path: 'dashboard',
  //     name: 'Dashboard',
  //     component: () => import('@/views/dashboard/index'),
  //     meta: {
  //       title: '首页',
  //       icon: 'home',
  //       affix: true
  //     }
  //   }]
  // },


  {
    path: '/company',
    component: Layout,
    redirect: 'noRedirect',
    name: 'CompanyList',
    meta: {
      title: '入驻企业',
      icon: 'form'
    },
    children: [{
        path: 'list',
        component: () => import('@/views/company/list'),
        name: 'CompanyList',
        meta: {
          title: '入驻企业',
          noCache: true,
          icon: 'account'
        }
      },
      {
        path: 'edit',
        component: () => import('@/views/company/edit'),
        name: 'editCompany',
        hidden: true,
        meta: {
          title: '添加/修改企业信息',
          noCache: true
        }
      },
      {
        path: 'talents',
        component: () => import('@/views/company/talents'),
        name: 'CompanyTalents',
        meta: {
          title: '人才管理',
          noCache: true,
          icon: 'system'
        }
      },
      {
        path: 'patent',
        name: 'CompanyPatent',
        component: () => import('@/views/company/patent'),
        meta: {
          title: '知识产权',
          noCache: true,
          icon: 'account'
        }
      },
      {
        path: 'project',
        name: 'CompanyPatent',
        component: () => import('@/views/company/project'),
        meta: {
          title: '企业项目',
          noCache: true,
          icon: 'account'
        }
      },
      {
        path: 'output',
        name: 'CompanyOutput',
        component: () => import('@/views/company/output'),
        meta: {
          title: '企业产值',
          noCache: true,
          icon: 'output'
        }
      },
      {
        path: 'product',
        name: 'CompanyProduct',
        component: () => import('@/views/company/product'),
        meta: {
          title: '企业产品',
          noCache: true,
          icon: 'account'
        }
      }
    ]
  },
  {
    path: '/invest',
    component: 'Layout',
    redirect: 'noRedirect',
    name: 'InvestCompany',
    meta: {
      title: '招商管理',
      icon: 'form'
    },
    children: [{
        path: 'activity',
        name: 'InvestActivity',
        component: '/invest/activity',
        meta: {
          title: '招商活动',
          noCache: true,
          icon: 'stock'
        }
      },
      {
        path: 'achievement',
        name: 'InvestAchievement',
        component: '/invest/achievement',
        meta: {
          title: '招商成果',
          noCache: true,
          icon: 'stock'
        }
      }
    ]
  },
  {
    path: '/notice',
    component: 'Layout',
    children: [{
      path: 'notice',
      name: 'Notice',
      component: '/notice/notice',
      meta: {
        title: '政策公告',
        icon: 'skill'
      }
    }]
  },
  {
    path: '/workstation',
    component: 'Layout',
    children: [{
      path: 'workstation',
      name: 'workstation',
      component: '/workstation/workstation',
      meta: {
        title: '工作站',
        icon: 'star'
      }
    }]
  },
  {
    path: '/friendlyLinks',
    component: Layout,
    children: [{
      path: 'friendlyLinks',
      name: 'FriendlyLinks',
      component: () => import('@/views/friendlyLinks/list'),
      meta: {
        title: '友情链接',
        icon: 'link'
      }
    }]
  },
  // {
  //   path: '/module',
  //   component: 'Layout',
  //   children: [{
  //     path: 'module',
  //     name: 'Module',
  //     component: () => import('@/views/module/module'),
  //     meta: {
  //       title: '动态模块',
  //       icon: 'link'
  //     }
  //   }]
  // },
  {
    path: '/module',
    component: 'Layout',
    redirect: 'noRedirect',
    name: 'module',
    meta: {
      title: '模块管理',
      icon: 'form'
    },
    children: [
      {
        path: 'talent',
        name: 'TalentModule',
        component: '/module/talent',
        meta: {
          title: '人才模块',
          noCache: true,
          icon: 'stock'
        }
      },
      {
        path: 'invest',
        name: 'InvestModule',
        component: '/module/invest',
        meta: {
          title: '招商模块',
          noCache: true,
          icon: 'stock'
        }
      },
      {
        path: 'research',
        name: 'ResearchModule',
        component: '/module/research',
        meta: {
          title: '研发模块',
          noCache: true,
          icon: 'stock'
        }
      },
      {
        path: 'industry',
        name: 'IndustryModule',
        component: '/module/industry',
        meta: {
          title: '类型模块',
          noCache: true,
          icon: 'stock'
        }
      }
    ]
  },
  backstageRouter,
  {
    path: '*',
    redirect: '/404',
    hidden: true
  }
]

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({
      y: 0
    }),
    routes: constantRoutes
  })

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
